@@ -9,20 +9,28 @@ from datetime import (
     datetime as Datetime,
     time as Time,
     timedelta as Timedelta,
-    timezone as Timezone)
+    timezone as Timezone,
+)
 from enum import Enum
 from json import dumps
 
-import pg8000
-from pg8000 import converters
-
 import pytest
 
 import pytz
 
+import pg8000.dbapi
+from pg8000.converters import (
+    INTERVAL,
+    PGInterval,
+    interval_in,
+    pg_interval_in,
+    pg_interval_out,
+)
+
 
 # Type conversion tests
 
+
 def test_time_roundtrip(cursor):
     t = Time(4, 5, 6)
     cursor.execute("SELECT cast(%s as time) as f1", (t,))
@@ -45,7 +53,7 @@ def test_null_roundtrip(cursor):
     cursor.execute("select current_setting('server_version')")
     version = cursor.fetchall()[0][0][:2]
 
-    if version.startswith('9'):
+    if version.startswith("9"):
         # Prior to PostgreSQL version 10 We can't just "SELECT %s" and set
         # None as the parameter, since it has no type.  That would result
         # in a PG error, "could not determine data type of parameter %s".
@@ -53,10 +61,11 @@ def test_null_roundtrip(cursor):
         # back.
         cursor.execute(
             "CREATE TEMPORARY TABLE TestNullWrite "
-            "(f1 int4, f2 timestamp, f3 varchar)")
+            "(f1 int4, f2 timestamp, f3 varchar)"
+        )
         cursor.execute(
-            "INSERT INTO TestNullWrite VALUES (%s, %s, %s)",
-            (None, None, None))
+            "INSERT INTO TestNullWrite VALUES (%s, %s, %s)", (None, None, None)
+        )
         cursor.execute("SELECT * FROM TestNullWrite")
         assert cursor.fetchall()[0] == [None, None, None]
 
@@ -68,9 +77,7 @@ def test_null_roundtrip(cursor):
 
 
 def test_decimal_roundtrip(cursor):
-    values = (
-        "1.1", "-1.1", "10000", "20000", "-1000000000.123456789", "1.0",
-        "12.44")
+    values = ("1.1", "-1.1", "10000", "20000", "-1000000000.123456789", "1.0", "12.44")
     for v in values:
         cursor.execute("SELECT %s as f1", (decimal.Decimal(v),))
         retval = cursor.fetchall()
@@ -84,15 +91,14 @@ def test_float_roundtrip(cursor):
 
 
 def test_float_plus_infinity_roundtrip(cursor):
-    v = float('inf')
+    v = float("inf")
     cursor.execute("SELECT cast(%s as double precision)", (v,))
     assert cursor.fetchall()[0][0] == v
 
 
 def test_str_roundtrip(cursor):
     v = "hello world"
-    cursor.execute(
-        "create temporary table test_str (f character varying(255))")
+    cursor.execute("create temporary table test_str (f character varying(255))")
     cursor.execute("INSERT INTO test_str VALUES (%s)", (v,))
     cursor.execute("SELECT * from test_str")
     assert cursor.fetchall()[0][0] == v
@@ -147,9 +153,9 @@ def test_int_roundtrip(con, cursor):
     int8 = 20
 
     MAP = {
-        int2: 'int2',
-        int4: 'int4',
-        int8: 'int8',
+        int2: "int2",
+        int4: "int4",
+        int8: "int8",
     }
 
     test_values = [
@@ -163,7 +169,8 @@ def test_int_roundtrip(con, cursor):
         (+2147483647, int4),
         (+2147483648, int8),
         (-9223372036854775807, int8),
-        (+9223372036854775807, int8)]
+        (+9223372036854775807, int8),
+    ]
 
     for value, typoid in test_values:
         cursor.execute("SELECT cast(%s as " + MAP[typoid] + ")", (value,))
@@ -174,13 +181,13 @@ def test_int_roundtrip(con, cursor):
 
 def test_bytea_roundtrip(cursor):
     cursor.execute(
-            "SELECT cast(%s as bytea)",
-            (pg8000.Binary(b"\x00\x01\x02\x03\x02\x01\x00"),))
+        "SELECT cast(%s as bytea)", (pg8000.Binary(b"\x00\x01\x02\x03\x02\x01\x00"),)
+    )
     assert cursor.fetchall()[0][0] == b"\x00\x01\x02\x03\x02\x01\x00"
 
 
 def test_bytearray_round_trip(cursor):
-    binary = b'\x00\x01\x02\x03\x02\x01\x00'
+    binary = b"\x00\x01\x02\x03\x02\x01\x00"
     cursor.execute("SELECT cast(%s as bytea)", (bytearray(binary),))
     assert cursor.fetchall()[0][0] == binary
 
@@ -188,7 +195,8 @@ def test_bytearray_round_trip(cursor):
 def test_bytearray_subclass_round_trip(cursor):
     class BClass(bytearray):
         pass
-    binary = b'\x00\x01\x02\x03\x02\x01\x00'
+
+    binary = b"\x00\x01\x02\x03\x02\x01\x00"
     cursor.execute("SELECT cast(%s as bytea)", (BClass(binary),))
     assert cursor.fetchall()[0][0] == binary
 
@@ -201,41 +209,42 @@ def test_timestamp_roundtrip(is_java, cursor):
     # Test that time zone doesn't affect it
     # Jython 2.5.3 doesn't have a time.tzset() so skip
     if not is_java:
-        orig_tz = os.environ.get('TZ')
-        os.environ['TZ'] = "America/Edmonton"
+        orig_tz = os.environ.get("TZ")
+        os.environ["TZ"] = "America/Edmonton"
         time.tzset()
 
         cursor.execute("SELECT cast(%s as timestamp)", (v,))
         assert cursor.fetchall()[0][0] == v
 
         if orig_tz is None:
-            del os.environ['TZ']
+            del os.environ["TZ"]
         else:
-            os.environ['TZ'] = orig_tz
+            os.environ["TZ"] = orig_tz
         time.tzset()
 
 
-def test_interval_repr():
-    v = pg8000.PGInterval(microseconds=123456789, days=2, months=24)
-    assert repr(v) == '<PGInterval 24 months 2 days 123456789 microseconds>'
+def test_pg_interval_repr():
+    v = PGInterval(microseconds=123456789, days=2, months=24)
+    assert repr(v) == "<PGInterval 24 months 2 days 123456789 microseconds>"
 
 
-def test_interval_in_1_year():
-    assert converters.pginterval_in('1 year') == pg8000.PGInterval(years=1)
+def test_pg_interval_in_1_year():
+    assert pg_interval_in("1 year") == PGInterval(years=1)
 
 
-def test_timedelta_in_2_months():
-    assert converters.timedelta_in('2 hours')
+def test_interval_in_2_months():
+    assert interval_in("2 hours")
 
 
-def test_interval_roundtrip(con, cursor):
-    con.register_in_adapter(1186, converters.pginterval_in)
-    v = pg8000.PGInterval(microseconds=123456789, days=2, months=24)
+def test_pg_interval_roundtrip(con, cursor):
+    con.register_in_adapter(INTERVAL, pg_interval_in)
+    con.register_out_adapter(PGInterval, INTERVAL, pg_interval_out)
+    v = PGInterval(microseconds=123456789, days=2, months=24)
     cursor.execute("SELECT cast(%s as interval)", (v,))
     assert cursor.fetchall()[0][0] == v
 
 
-def test_timedelta_roundtrip(cursor):
+def test_interval_roundtrip(cursor):
     v = Timedelta(seconds=30)
     cursor.execute("SELECT cast(%s as interval)", (v,))
     assert cursor.fetchall()[0][0] == v
@@ -243,23 +252,23 @@ def test_timedelta_roundtrip(cursor):
 
 def test_enum_str_round_trip(cursor):
     try:
-        cursor.execute(
-            "create type lepton as enum ('electron', 'muon', 'tau')")
+        cursor.execute("create type lepton as enum ('electron', 'muon', 'tau')")
 
-        v = 'muon'
+        v = "muon"
         cursor.execute("SELECT cast(%s as lepton) as f1", (v,))
         retval = cursor.fetchall()
         assert retval[0][0] == v
         cursor.execute("CREATE TEMPORARY TABLE testenum (f1 lepton)")
         cursor.execute(
-            "INSERT INTO testenum VALUES (cast(%s as lepton))", ('electron',))
+            "INSERT INTO testenum VALUES (cast(%s as lepton))", ("electron",)
+        )
     finally:
         cursor.execute("drop table testenum")
         cursor.execute("drop type lepton")
 
 
 def test_enum_custom_round_trip(con, cursor):
-    class Lepton():
+    class Lepton:
         # Implements PEP 435 in the minimal fashion needed
         __members__ = OrderedDict()
 
@@ -281,7 +290,7 @@ def test_enum_custom_round_trip(con, cursor):
         lepton_oid = cursor.fetchall()[0][0]
         con.register_out_adapter(Lepton, lepton_oid, lepton_out)
 
-        v = Lepton('muon', '2')
+        v = Lepton("muon", "2")
         cursor.execute("SELECT %s", (v,))
         assert cursor.fetchall()[0][0] == v.value
     finally:
@@ -290,9 +299,9 @@ def test_enum_custom_round_trip(con, cursor):
 
 def test_enum_py_round_trip(cursor):
     class Lepton(Enum):
-        electron = '1'
-        muon = '2'
-        tau = '3'
+        electron = "1"
+        muon = "2"
+        tau = "3"
 
     try:
         cursor.execute("create type lepton as enum ('1', '2', '3')")
@@ -303,33 +312,33 @@ def test_enum_py_round_trip(cursor):
 
         cursor.execute("CREATE TEMPORARY TABLE testenum (f1 lepton)")
         cursor.execute(
-            "INSERT INTO testenum VALUES (cast(%s as lepton))",
-            (Lepton.electron,))
+            "INSERT INTO testenum VALUES (cast(%s as lepton))", (Lepton.electron,)
+        )
     finally:
         cursor.execute("drop table testenum")
         cursor.execute("drop type lepton")
 
 
 def test_xml_roundtrip(cursor):
-    v = '<genome>gatccgagtac</genome>'
+    v = "<genome>gatccgagtac</genome>"
     cursor.execute("select xmlparse(content %s) as f1", (v,))
     assert cursor.fetchall()[0][0] == v
 
 
 def test_uuid_roundtrip(cursor):
-    v = uuid.UUID('911460f2-1f43-fea2-3e2c-e01fd5b5069d')
+    v = uuid.UUID("911460f2-1f43-fea2-3e2c-e01fd5b5069d")
     cursor.execute("select cast(%s as uuid)", (v,))
     assert cursor.fetchall()[0][0] == v
 
 
 def test_inet_roundtrip_network(cursor):
-    v = ipaddress.ip_network('192.168.0.0/28')
+    v = ipaddress.ip_network("192.168.0.0/28")
     cursor.execute("select cast(%s as inet)", (v,))
     assert cursor.fetchall()[0][0] == v
 
 
 def test_inet_roundtrip_address(cursor):
-    v = ipaddress.ip_address('192.168.0.1')
+    v = ipaddress.ip_address("192.168.0.1")
     cursor.execute("select cast(%s as inet)", (v,))
     assert cursor.fetchall()[0][0] == v
 
@@ -356,14 +365,14 @@ def test_int2vector_in(cursor):
 
 def test_timestamp_tz_out(cursor):
     cursor.execute(
-        "SELECT '2001-02-03 04:05:06.17 America/Edmonton'"
-        "::timestamp with time zone")
+        "SELECT '2001-02-03 04:05:06.17 America/Edmonton'" "::timestamp with time zone"
+    )
     retval = cursor.fetchall()
     dt = retval[0][0]
     assert dt.tzinfo is not None, "no tzinfo returned"
     assert dt.astimezone(Timezone.utc) == Datetime(
-        2001, 2, 3, 11, 5, 6, 170000, Timezone.utc), \
-        "retrieved value match failed"
+        2001, 2, 3, 11, 5, 6, 170000, Timezone.utc
+    ), "retrieved value match failed"
 
 
 def test_timestamp_tz_roundtrip(is_java, cursor):
@@ -384,14 +393,17 @@ def test_timestamp_mismatch(is_java, cursor):
             cursor.execute(
                 "CREATE TEMPORARY TABLE TestTz "
                 "(f1 timestamp with time zone, "
-                "f2 timestamp without time zone)")
+                "f2 timestamp without time zone)"
+            )
             cursor.execute(
-                "INSERT INTO TestTz (f1, f2) VALUES (%s, %s)", (
+                "INSERT INTO TestTz (f1, f2) VALUES (%s, %s)",
+                (
                     # insert timestamp into timestamptz field (v1)
                     Datetime(2001, 2, 3, 4, 5, 6, 170000),
                     # insert timestamptz into timestamp field (v2)
-                    mst.localize(Datetime(
-                        2001, 2, 3, 4, 5, 6, 170000))))
+                    mst.localize(Datetime(2001, 2, 3, 4, 5, 6, 170000)),
+                ),
+            )
             cursor.execute("SELECT f1, f2 FROM TestTz")
             retval = cursor.fetchall()
 
@@ -433,7 +445,7 @@ def test_boolean_in(cursor):
 
 
 def test_numeric_out(cursor):
-    for num in ('5000', '50.34'):
+    for num in ("5000", "50.34"):
         cursor.execute("SELECT " + num + "::numeric")
         assert str(cursor.fetchall()[0][0]) == num
 
@@ -479,12 +491,15 @@ def test_text_out(cursor):
 
 
 def test_interval_in(con, cursor):
-    con.register_in_adapter(1186, pg8000.converters.pginterval_in)
-    cursor.execute(
-        "SELECT '1 month 16 days 12 hours 32 minutes 64 seconds'::interval")
-    expected_value = pg8000.PGInterval(
-        microseconds=(12 * 60 * 60 * 1000 * 1000) +
-        (32 * 60 * 1000 * 1000) + (64 * 1000 * 1000), days=16, months=1)
+    con.register_in_adapter(INTERVAL, pg_interval_in)
+    cursor.execute("SELECT '1 month 16 days 12 hours 32 minutes 64 seconds'::interval")
+    expected_value = PGInterval(
+        microseconds=(12 * 60 * 60 * 1000 * 1000)
+        + (32 * 60 * 1000 * 1000)
+        + (64 * 1000 * 1000),
+        days=16,
+        months=1,
+    )
     assert cursor.fetchall()[0][0] == expected_value
 
 
@@ -507,7 +522,8 @@ def test_timestamp_out(cursor):
 def test_int4_array_out(cursor):
     cursor.execute(
         "SELECT '{1,2,3,4}'::INT[] AS f1, '{{1,2,3},{4,5,6}}'::INT[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT[][][] AS f3"
+    )
     f1, f2, f3 = cursor.fetchone()
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -518,7 +534,8 @@ def test_int2_array_out(cursor):
     cursor.execute(
         "SELECT '{1,2,3,4}'::INT2[] AS f1, "
         "'{{1,2,3},{4,5,6}}'::INT2[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT2[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT2[][][] AS f3"
+    )
     f1, f2, f3 = cursor.fetchone()
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -529,7 +546,8 @@ def test_int8_array_out(cursor):
     cursor.execute(
         "SELECT '{1,2,3,4}'::INT8[] AS f1, "
         "'{{1,2,3},{4,5,6}}'::INT8[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT8[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::INT8[][][] AS f3"
+    )
     f1, f2, f3 = cursor.fetchone()
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -541,19 +559,20 @@ def test_bool_array_out(cursor):
         "SELECT '{TRUE,FALSE,FALSE,TRUE}'::BOOL[] AS f1, "
         "'{{TRUE,FALSE,TRUE},{FALSE,TRUE,FALSE}}'::BOOL[][] AS f2, "
         "'{{{TRUE,FALSE},{FALSE,TRUE}},{{NULL,TRUE},{FALSE,FALSE}}}'"
-        "::BOOL[][][] AS f3")
+        "::BOOL[][][] AS f3"
+    )
     f1, f2, f3 = cursor.fetchone()
     assert f1 == [True, False, False, True]
     assert f2 == [[True, False, True], [False, True, False]]
-    assert f3 == [
-        [[True, False], [False, True]], [[None, True], [False, False]]]
+    assert f3 == [[[True, False], [False, True]], [[None, True], [False, False]]]
 
 
 def test_float4_array_out(cursor):
     cursor.execute(
         "SELECT '{1,2,3,4}'::FLOAT4[] AS f1, "
         "'{{1,2,3},{4,5,6}}'::FLOAT4[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::FLOAT4[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::FLOAT4[][][] AS f3"
+    )
     f1, f2, f3 = cursor.fetchone()
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -564,7 +583,8 @@ def test_float8_array_out(cursor):
     cursor.execute(
         "SELECT '{1,2,3,4}'::FLOAT8[] AS f1, "
         "'{{1,2,3},{4,5,6}}'::FLOAT8[][] AS f2, "
-        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::FLOAT8[][][] AS f3")
+        "'{{{1,2},{3,4}},{{NULL,6},{7,8}}}'::FLOAT8[][][] AS f3"
+    )
     f1, f2, f3 = cursor.fetchone()
     assert f1 == [1, 2, 3, 4]
     assert f2 == [[1, 2, 3], [4, 5, 6]]
@@ -572,8 +592,7 @@ def test_float8_array_out(cursor):
 
 
 def test_int_array_roundtrip_small(cursor):
-    """ send small int array, should be sent as INT2[]
-    """
+    """send small int array, should be sent as INT2[]"""
     cursor.execute("SELECT cast(%s as int2[])", ([1, 2, 3],))
     assert cursor.fetchall()[0][0], [1, 2, 3]
     column_name, column_typeoid = cursor.description[0][0:2]
@@ -581,8 +600,7 @@ def test_int_array_roundtrip_small(cursor):
 
 
 def test_int_array_roundtrip_multi(cursor):
-    """ test multi-dimensional array, should be sent as INT2[]
-    """
+    """test multi-dimensional array, should be sent as INT2[]"""
     cursor.execute("SELECT cast(%s as int2[])", ([[1, 2], [3, 4]],))
     assert cursor.fetchall()[0][0] == [[1, 2], [3, 4]]
 
@@ -591,8 +609,7 @@ def test_int_array_roundtrip_multi(cursor):
 
 
 def test_int4_array_roundtrip(cursor):
-    """ a larger value should kick it up to INT4[]...
-    """
+    """a larger value should kick it up to INT4[]..."""
     cursor.execute("SELECT cast(%s as int4[])", ([70000, 2, 3],))
     assert cursor.fetchall()[0][0] == [70000, 2, 3]
     column_name, column_typeoid = cursor.description[0][0:2]
@@ -600,11 +617,9 @@ def test_int4_array_roundtrip(cursor):
 
 
 def test_int8_array_roundtrip(cursor):
-    """ a much larger value should kick it up to INT8[]...
-    """
+    """a much larger value should kick it up to INT8[]..."""
     cursor.execute("SELECT cast(%s as int8[])", ([7000000000, 2, 3],))
-    assert cursor.fetchall()[0][0] == [7000000000, 2, 3], \
-        "retrieved value match failed"
+    assert cursor.fetchall()[0][0] == [7000000000, 2, 3], "retrieved value match failed"
     column_name, column_typeoid = cursor.description[0][0:2]
     assert column_typeoid == 1016, "type should be INT8[]"
 
@@ -633,11 +648,8 @@ def test_bool_array_roundtrip(cursor):
         ("SELECT '{a,b,c}'::CSTRING[] AS f1", ["a", "b", "c"]),
         ("SELECT '{a,b,c}'::NAME[] AS f1", ["a", "b", "c"]),
         ("SELECT '{}'::text[];", []),
-        (
-            "SELECT '{NULL,\"NULL\",NULL,\"\"}'::text[];",
-            [None, 'NULL', None, ""]
-        )
-    ]
+        ('SELECT \'{NULL,"NULL",NULL,""}\'::text[];', [None, "NULL", None, ""]),
+    ],
 )
 def test_string_array_out(cursor, test_input, expected):
     cursor.execute(test_input)
@@ -647,7 +659,10 @@ def test_string_array_out(cursor, test_input, expected):
 def test_numeric_array_out(cursor):
     cursor.execute("SELECT '{1.1,2.2,3.3}'::numeric[] AS f1")
     assert cursor.fetchone()[0] == [
-        decimal.Decimal("1.1"), decimal.Decimal("2.2"), decimal.Decimal("3.3")]
+        decimal.Decimal("1.1"),
+        decimal.Decimal("2.2"),
+        decimal.Decimal("3.3"),
+    ]
 
 
 def test_numeric_array_roundtrip(cursor):
@@ -658,15 +673,20 @@ def test_numeric_array_roundtrip(cursor):
 
 def test_string_array_roundtrip(cursor):
     v = [
-        "Hello!", "World!", "abcdefghijklmnopqrstuvwxyz", "",
+        "Hello!",
+        "World!",
+        "abcdefghijklmnopqrstuvwxyz",
+        "",
         "A bunch of random characters:",
-        " ~!@#$%^&*()_+`1234567890-=[]\\{}|{;':\",./<>?\t", None]
+        " ~!@#$%^&*()_+`1234567890-=[]\\{}|{;':\",./<>?\t",
+        None,
+    ]
     cursor.execute("SELECT cast(%s as varchar[])", (v,))
     assert cursor.fetchall()[0][0] == v
 
 
 def test_array_string_escape():
-    v = "\""
+    v = '"'
     res = pg8000.converters.array_string_escape(v)
     assert res == '"\\""'
 
@@ -684,8 +704,8 @@ def test_macaddr(cursor):
 
 def test_tsvector_roundtrip(cursor):
     cursor.execute(
-        "SELECT cast(%s as tsvector)",
-        ('a fat cat sat on a mat and ate a fat rat',))
+        "SELECT cast(%s as tsvector)", ("a fat cat sat on a mat and ate a fat rat",)
+    )
     retval = cursor.fetchall()
     assert retval[0][0] == "'a' 'and' 'ate' 'cat' 'fat' 'mat' 'on' 'rat' 'sat'"
 
@@ -697,65 +717,61 @@ def test_hstore_roundtrip(cursor):
 
 
 def test_json_roundtrip(cursor):
-    val = {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003}
+    val = {"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}
     cursor.execute("SELECT cast(%s as jsonb)", (dumps(val),))
     assert cursor.fetchall()[0][0] == val
 
 
 def test_jsonb_roundtrip(cursor):
-    val = {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003}
+    val = {"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}
     cursor.execute("SELECT cast(%s as jsonb)", (dumps(val),))
     retval = cursor.fetchall()
     assert retval[0][0] == val
 
 
 def test_json_access_object(cursor):
-    val = {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003}
-    cursor.execute("SELECT cast(%s as json) -> %s", (dumps(val), 'name'))
+    val = {"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}
+    cursor.execute("SELECT cast(%s as json) -> %s", (dumps(val), "name"))
     retval = cursor.fetchall()
-    assert retval[0][0] == 'Apollo 11 Cave'
+    assert retval[0][0] == "Apollo 11 Cave"
 
 
 def test_jsonb_access_object(cursor):
-    val = {'name': 'Apollo 11 Cave', 'zebra': True, 'age': 26.003}
-    cursor.execute("SELECT cast(%s as jsonb) -> %s", (dumps(val), 'name'))
+    val = {"name": "Apollo 11 Cave", "zebra": True, "age": 26.003}
+    cursor.execute("SELECT cast(%s as jsonb) -> %s", (dumps(val), "name"))
     retval = cursor.fetchall()
-    assert retval[0][0] == 'Apollo 11 Cave'
+    assert retval[0][0] == "Apollo 11 Cave"
 
 
 def test_json_access_array(cursor):
     val = [-1, -2, -3, -4, -5]
-    cursor.execute(
-        "SELECT cast(%s as json) -> cast(%s as int)", (dumps(val), 2))
+    cursor.execute("SELECT cast(%s as json) -> cast(%s as int)", (dumps(val), 2))
     assert cursor.fetchall()[0][0] == -3
 
 
 def test_jsonb_access_array(cursor):
     val = [-1, -2, -3, -4, -5]
-    cursor.execute(
-        "SELECT cast(%s as jsonb) -> cast(%s as int)", (dumps(val), 2))
+    cursor.execute("SELECT cast(%s as jsonb) -> cast(%s as int)", (dumps(val), 2))
     assert cursor.fetchall()[0][0] == -3
 
 
 def test_jsonb_access_path(cursor):
-    j = {
-        "a": [1, 2, 3],
-        "b": [4, 5, 6]}
+    j = {"a": [1, 2, 3], "b": [4, 5, 6]}
 
-    path = ['a', '2']
+    path = ["a", "2"]
 
     cursor.execute("SELECT cast(%s as jsonb) #>> %s", (dumps(j), path))
     assert cursor.fetchall()[0][0] == str(j[path[0]][int(path[1])])
 
 
 def test_infinity_timestamp_roundtrip(cursor):
-    v = 'infinity'
+    v = "infinity"
     cursor.execute("SELECT cast(%s as timestamp) as f1", (v,))
     assert cursor.fetchall()[0][0] == v
 
 
 def test_point_roundtrip(cursor):
-    v = '(2.3,1)'
+    v = "(2.3,1)"
     cursor.execute("SELECT cast(%s as point) as f1", (v,))
     assert cursor.fetchall()[0][0] == v
 
